﻿using System;
using System.Globalization;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;

namespace ListBoxPlanets
{
    public partial class Page : UserControl
    {
        public Page()
        {
            InitializeComponent();
        }
    }

    // Derive from ListBox so we can override PrepareContainerForItemOverride
    // and set bindings for Canvas.Left and .Top (was not able to do this in
    // ListBox.ItemContainerStyle)
    public class ListBox : System.Windows.Controls.ListBox
    {
        protected override void PrepareContainerForItemOverride(DependencyObject element, object item)
        {
            base.PrepareContainerForItemOverride(element, item);
            // Get ListBoxItem
            ListBoxItem listBoxItem = (ListBoxItem)element;
            // Create appropriate binding
            Binding orbitBinding = new Binding("Orbit");
            orbitBinding.Converter = new PlanetsListBox.ConvertOrbit();
            orbitBinding.ConverterParameter = 0.707;
            // Bind Canvas properties
            listBoxItem.SetBinding(Canvas.LeftProperty, orbitBinding);
            listBoxItem.SetBinding(Canvas.TopProperty, orbitBinding);
        }
    }

    // Custom IValueConverter to provide ToolTip contents (was not able to do
    // this in XAML because Binding didn't hook up as expected)
    public class FormatForToolTip : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            // Get SolarSystemObject
            PlanetsListBox.SolarSystemObject planet = (PlanetsListBox.SolarSystemObject)value;
            // Create ToolTip contents
            StackPanel panel = new StackPanel { Width = 250 };
            panel.Children.Add(new TextBlock { Text = planet.Name, FontSize = 12, FontWeight = FontWeights.Bold });
            panel.Children.Add(new TextBlock { Text = string.Format("Orbit: {0} AU", planet.Orbit), FontSize = 12 });
            panel.Children.Add(new TextBlock { Text = planet.Details, FontSize = 12, TextWrapping=TextWrapping.Wrap });
            // Return converted value
            return panel;
        }
        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotSupportedException();
        }
    }
}
